@@ -32,11 +32,15 @@ def should_selective_backprop(
     alternate with vanilla minibatch steps.
 
     Args:
-        current_duration (float): The elapsed training duration, on [0.0; 1.0)
+        current_duration (float): The elapsed training duration. Must be
+            within :math:`[0.0, 1.0)`.
         batch_idx (int): The current batch within the epoch
-        start (float): The duration at which selective backprop should be enabled
-        end (float): The duration at which selective backprop should be disabled
-        interrupt (int): The number of batches between vanilla minibatch gradient updates
+        start (float, optional): The duration at which selective backprop
+            should be enabled. Default: ``0.5``.
+        end (float, optional): The duration at which selective backprop
+            should be disabled Default: ``0.9``.
+        interrupt (int, optional): The number of batches between vanilla
+            minibatch gradient updates Default: ``2``.
 
     Returns:
         bool: If selective backprop should be performed on this batch.
@@ -47,11 +51,11 @@ def should_selective_backprop(
     return is_interval and is_step
 
 
-def select_using_loss(X: torch.Tensor,
-                      y: torch.Tensor,
+def select_using_loss(input: torch.Tensor,
+                      target: torch.Tensor,
                       model: Callable[[Tensors], Tensor],
                       loss_fun: Callable,
-                      keep: float,
+                      keep: float = 0.5,
                       scale_factor: float = 1) -> Tuple[torch.Tensor, torch.Tensor]:
     """Selectively backpropagate gradients from a subset of each batch (`Jiang et al, 2019 <https://\\
     arxiv.org/abs/1910.00762>`_).
@@ -67,15 +71,15 @@ def select_using_loss(X: torch.Tensor,
     will still be used for the weight gradient computation.
 
     Args:
-        X: Input tensor to prune
-        y: Output tensor to prune
-        model: Model with which to predict outputs
-        loss_fun: Loss function of the form ``loss(outputs, targets, reduction='none')``.
+        input (torch.Tensor): Input tensor to prune
+        target (torch.Tensor): Output tensor to prune
+        model (Callable): Model with which to predict outputs
+        loss_fun (Callable): Loss function of the form ``loss(outputs, targets, reduction='none')``.
             The function must take the keyword argument ``reduction='none'``
             to ensure that per-sample losses are returned.
-        keep: Fraction of examples in the batch to keep
-        scale_factor: Multiplier between 0 and 1 for spatial size. Downsampling
-            requires the input tensor to be at least 3D.
+        keep (float, optional): Fraction of examples in the batch to keep. Default: ``0.5``.
+        scale_factor (float, optional): Multiplier between 0 and 1 for spatial size. Downsampling
+            requires the input tensor to be at least 3D. Default: ``1``.
 
     Returns:
         (torch.Tensor, torch.Tensor): The pruned batch of inputs and targets
@@ -98,9 +102,9 @@ def select_using_loss(X: torch.Tensor,
 
     interp_mode = "bilinear"
     if scale_factor != 1:
-        if X.dim() not in INTERPOLATE_MODES:
-            raise ValueError(f"Input must be 3D, 4D, or 5D if scale_factor != 1, got {X.dim()}")
-        interp_mode = INTERPOLATE_MODES[X.dim()]
+        if input.dim() not in INTERPOLATE_MODES:
+            raise ValueError(f"Input must be 3D, 4D, or 5D if scale_factor != 1, got {input.dim()}")
+        interp_mode = INTERPOLATE_MODES[input.dim()]
 
     if scale_factor > 1:
         raise ValueError("scale_factor must be <= 1")
@@ -113,17 +117,17 @@ def select_using_loss(X: torch.Tensor,
         raise TypeError("Loss function must be callable")
 
     with torch.no_grad():
-        N = X.shape[0]
+        N = input.shape[0]
 
         # Maybe interpolate
         if scale_factor < 1:
-            X_scaled = F.interpolate(X, scale_factor=scale_factor, mode=interp_mode)
+            X_scaled = F.interpolate(input, scale_factor=scale_factor, mode=interp_mode)
         else:
-            X_scaled = X
+            X_scaled = input
 
         # Get per-examples losses
         out = model(X_scaled)
-        losses = loss_fun(out, y, reduction="none")
+        losses = loss_fun(out, target, reduction="none")
 
         # Sort losses
         sorted_idx = torch.argsort(losses)
@@ -136,7 +140,7 @@ def select_using_loss(X: torch.Tensor,
         select_percs_idx = np.random.choice(N, n_select, replace=False, p=probs)
         select_idx = sorted_idx[select_percs_idx]
 
-    return X[select_idx], y[select_idx]
+    return input[select_idx], target[select_idx]
 
 
 class SelectiveBackprop(Algorithm):
@@ -159,12 +163,16 @@ class SelectiveBackprop(Algorithm):
     alternate with vanilla minibatch steps.
 
     Args:
-        start: SB interval start as fraction of training duration
-        end: SB interval end as fraction of training duration
-        keep: fraction of minibatch to select and keep for gradient computation
-        scale_factor: scale for downsampling input for selection forward pass
-        interrupt: interrupt SB with a vanilla minibatch step every
-            ``interrupt`` batches
+        start (float, optional): SB interval start as fraction of training duration
+            Default: ``0.5``.
+        end (float, optional): SB interval end as fraction of training duration
+            Default: ``0.9``.
+        keep (float, optional): fraction of minibatch to select and keep for gradient computation
+            Default: ``0.5``.
+        scale_factor (float, optional): scale for downsampling input for selection forward pass
+            Default: ``0.5``.
+        interrupt (int, optional): interrupt SB with a vanilla minibatch step every
+            ``interrupt`` batches. Default: ``2``.
     """
 
     def __init__(self,
