@@ -1,16 +1,14 @@
 # Copyright 2021 MosaicML. All Rights Reserved.
 
-"""Callbacks provide hooks that can run at each training loop :class:`~composer.core.event.Event`
+"""Callbacks that run at each training loop :class:`~composer.core.event.Event`.
 
 Each callback inherits from the :class:`~composer.core.callback.Callback` base class. See detailed description and
 examples for writing your own callbacks at the :class:`~composer.core.callback.Callback` base class.
 """
-from composer.callbacks.callback_hparams import CallbackHparams as CallbackHparams
-from composer.callbacks.callback_hparams import GradMonitorHparams as GradMonitorHparams
-from composer.callbacks.callback_hparams import LRMonitorHparams as LRMonitorHparams
-from composer.callbacks.callback_hparams import MemoryMonitorHparams as MemoryMonitorHparams
-from composer.callbacks.callback_hparams import RunDirectoryUploaderHparams as RunDirectoryUploaderHparams
-from composer.callbacks.callback_hparams import SpeedMonitorHparams as SpeedMonitorHparams
+from composer.callbacks.callback_hparams import (CallbackHparams, CheckpointSaverHparams, GradMonitorHparams,
+                                                 LRMonitorHparams, MemoryMonitorHparams, RunDirectoryUploaderHparams,
+                                                 SpeedMonitorHparams)
+from composer.callbacks.checkpoint_saver import CheckpointSaver
 from composer.callbacks.grad_monitor import GradMonitor
 from composer.callbacks.lr_monitor import LRMonitor
 from composer.callbacks.memory_monitor import MemoryMonitor
@@ -23,4 +21,13 @@ __all__ = [
     "MemoryMonitor",
     "RunDirectoryUploader",
     "SpeedMonitor",
+    "CheckpointSaver",
+    # hparams objects
+    "CallbackHparams",
+    "CheckpointSaverHparams",
+    "GradMonitorHparams",
+    "LRMonitorHparams",
+    "MemoryMonitorHparams",
+    "RunDirectoryUploaderHparams",
+    "SpeedMonitorHparams",
 ]
