@@ -1,15 +1,18 @@
 # Copyright 2021 MosaicML. All Rights Reserved.
 
-"""Central parts of composer such as :class:`~.engine.Engine`, base class for critical components such as
+"""Central components used by other modules.
+
+Central parts of composer such as :class:`~.engine.Engine`, base class for critical components such as
 :class:`~.algorithm.Algorithm` and :class:`~.callback.Callback` and other useful functionality such as
-:class:`~.logger.Logger` and :class:`~.time.Timer` are implemented under core."""
+:class:`~.logger.Logger` and :class:`~.time.Timer` are implemented under core.
+"""
 
-from composer.core import types as types
 from composer.core.algorithm import Algorithm as Algorithm
 from composer.core.callback import Callback as Callback
 from composer.core.data_spec import DataSpec as DataSpec
 from composer.core.engine import Engine as Engine
 from composer.core.engine import Trace as Trace
+from composer.core.evaluator import Evaluator as Evaluator
 from composer.core.event import Event as Event
 from composer.core.logging import Logger as Logger
 from composer.core.state import State as State
