@@ -1,5 +1,7 @@
 # Copyright 2021 MosaicML. All Rights Reserved.
 
+"""Serialization interface used by checkpointing."""
+
 from __future__ import annotations
 
 from typing import TYPE_CHECKING
@@ -7,6 +9,8 @@ from typing import TYPE_CHECKING
 if TYPE_CHECKING:
     from composer.core.types import StateDict
 
+__all__ = ["Serializable"]
+
 
 class Serializable:
     """Interface for serialization; used by checkpointing."""
@@ -14,7 +18,7 @@ class Serializable:
     def state_dict(self) -> StateDict:
         """Returns a dictionary representing the internal state.
 
-        The returned dictionary must be pickale-able via :meth:`torch.save`.
+        The returned dictionary must be pickale-able via :func:`torch.save`.
 
         Returns:
             StateDict: The state of the object
@@ -25,7 +29,6 @@ class Serializable:
         """Restores the state of the object.
 
         Args:
-            state (StateDict): The state of the object,
-                as previously returned by :meth:`.state_dict`
+            state (StateDict): The state of the object, as previously returned by :meth:`.state_dict`
         """
         pass
