@@ -1,5 +1,6 @@
 # Copyright 2021 MosaicML. All Rights Reserved.
 
+"""A collection of common torchmetrics and loss functions."""
 from __future__ import annotations
 
 from typing import TYPE_CHECKING, Optional, Tuple
@@ -13,20 +14,21 @@ from torchmetrics.utilities.data import to_categorical
 if TYPE_CHECKING:
     from composer.core.types import Tensor
 
+__all__ = ["MIoU", "Dice", "CrossEntropyLoss", "soft_cross_entropy"]
+
 
 class MIoU(Metric):
-    """Torchmetric mean Intersection-over-Union (mIoU) implementation.
+    """Torchmetrics mean Intersection-over-Union (mIoU) implementation.
 
     IoU calculates the intersection area between the predicted class mask and the label class mask.
     The intersection is then divided by the area of the union of the predicted and label masks.
     This measures the quality of predicted class mask with respect to the label. The IoU for each
     class is then averaged and the final result is the mIoU score. Implementation is primarily
-    based on mmsegmentation:
-    https://github.com/open-mmlab/mmsegmentation/blob/master/mmseg/core/evaluation/metrics.py#L132
+    based on `mmsegmentation <https://github.com/open-mmlab/mmsegmentation/blob/master/mmseg/core/evaluation/metrics.py#L132>`_
 
     Args:
         num_classes (int): the number of classes in the segmentation task.
-        ignore_index (int): the index to ignore when computing mIoU. Default is -1.
+        ignore_index (int, optional): the index to ignore when computing mIoU. Default: ``-1``.
     """
 
     def __init__(self, num_classes: int, ignore_index: int = -1):
@@ -63,12 +65,15 @@ class Dice(Metric):
     The Dice Coefficient measures how similar predictions and targets are.
     More concretely, it is computed as 2 * the Area of Overlap divided by
     the total number of pixels in both images.
+
+    Args:
+        num_classes (int): the number of classes in the segmentation task.
     """
 
-    def __init__(self, nclass):
+    def __init__(self, num_classes):
         super().__init__(dist_sync_on_step=True)
         self.add_state("n_updates", default=torch.zeros(1), dist_reduce_fx="sum")
-        self.add_state("dice", default=torch.zeros((nclass,)), dist_reduce_fx="sum")
+        self.add_state("dice", default=torch.zeros((num_classes,)), dist_reduce_fx="sum")
 
     def update(self, pred, target):
         """Update the state based on new predictions and targets."""
@@ -140,7 +145,7 @@ def ensure_targets_one_hot(input: Tensor, targets: Tensor) -> Tensor:
     return targets
 
 
-def check_for_index_targets(targets: Tensor) -> bool:
+def _check_for_index_targets(targets: Tensor) -> bool:
     """Checks if a given set of targets are indices by looking at the type."""
     index_types = ['torch.LongTensor', 'torch.cuda.LongTensor']
     return targets.type() in index_types
@@ -153,7 +158,39 @@ def soft_cross_entropy(input: Tensor,
                        ignore_index: int = -100,
                        reduce: Optional[bool] = None,
                        reduction: str = 'mean'):
-    """Drop-in replacement for ``torch.CrossEntropy`` that can handle dense labels.
+    r"""Drop-in replacement for :class:`~torch.nn.CrossEntropyLoss` that can handle class indices or one-hot labels.
+
+    Args:
+        input (torch.Tensor) : :math:`(N, C)` where `C = number of classes` or :math:`(N, C, H, W)`
+            in case of 2D Loss, or :math:`(N, C, d_1, d_2, ..., d_K)` where :math:`K \geq 1`
+            in the case of K-dimensional loss. `input` is expected to contain unnormalized scores
+            (often referred to as logits).
+        target (torch.Tensor) : If containing class indices, shape :math:`(N)` where each value is
+            :math:`0 \leq \text{targets}[i] \leq C-1`, or :math:`(N, d_1, d_2, ..., d_K)` with
+            :math:`K \geq 1` in the case of K-dimensional loss. If containing class probabilities,
+            same shape as the input.
+        weight (torch.Tensor, optional): a manual rescaling weight given to each
+            class. If given, has to be a Tensor of size `C`. Default: ``None``.
+        size_average (bool, optional): Deprecated (see `reduction`). By default,
+            the losses are averaged over each loss element in the batch. Note that for
+            some losses, there multiple elements per sample. If the field ``size_average``
+            is set to ``False``, the losses are instead summed for each minibatch. Ignored
+            when reduce is ``False``. Default: ``True``
+        ignore_index (int, optional): Specifies a target value that is ignored
+            and does not contribute to the input gradient. When ``size_average`` is
+            ``True``, the loss is averaged over non-ignored targets. Note that
+            ``ignore_index`` is only applicable when the target contains class indices.
+            Default: ``-100``
+        reduce (bool, optional): Deprecated (see ``reduction``). By default, the
+            losses are averaged or summed over observations for each minibatch depending
+            on `size_average`. When ``reduce`` is ``False``, returns a loss per
+            batch element instead and ignores `size_average`. Default: ``True``
+        reduction (str, optional): Specifies the reduction to apply to the output:
+            ``'none'`` | ``'mean'`` | ``'sum'``. ``'none'``: no reduction will be applied,
+            ``'mean'``: the sum of the output will be divided by the number of
+            elements in the output, ``'sum'``: the output will be summed. Note: ``size_average``
+            and ``reduce`` are in the process of being deprecated, and in the meantime,
+            specifying either of those two args will override ``reduction``. Default: ``'mean'``
 
     This function will be obsolete with `this update <https://github.com/pytorch/pytorch/pull/61044>`_.
     """
@@ -184,10 +221,17 @@ def soft_cross_entropy(input: Tensor,
 
 
 class CrossEntropyLoss(Metric):
-    """Torchmetric cross entropy loss implementation.
+    """Torchmetrics cross entropy loss implementation.
 
-    This class implements cross entropy loss as a `torchmetric` so that it can be returned by the
-    :meth:`~composer.models.ComposerModel.metric` function in :class:`ComposerModel`.
+    This class implements cross entropy loss as a :class:`torchmetrics.Metric` so that it can be returned by the
+    :meth:`~.ComposerModel.metrics`.
+
+    Args:
+        ignore_index (int, optional): Specifies a target value that is ignored
+            and does not contribute to the input gradient. ``ignore_index`` is only applicable when the target
+            contains class indices. Default: ``-100``.
+
+        dist_sync_on_step (bool, optional): sync distributed metrics every step. Default: ``False``.
     """
 
     def __init__(self, ignore_index: int = -100, dist_sync_on_step=False):
