@@ -1,5 +1,7 @@
 # Copyright 2021 MosaicML. All Rights Reserved.
 
+"""A :class:`.ComposerClassifier` wrapper around the torchvision implementations of the ResNet model family."""
+
 from typing import List, Optional
 
 from torchvision.models import resnet
@@ -7,23 +9,32 @@ from torchvision.models import resnet
 from composer.models.base import ComposerClassifier
 from composer.models.model_hparams import Initializer
 
+__all__ = ["ComposerResNet"]
+
 
 class ComposerResNet(ComposerClassifier):
-    """ResNet model family extending :class:`ComposerClassifier`.
+    """A :class:`.ComposerClassifier` wrapper around the torchvision implementations of the ResNet model family.
 
-    See this `paper <https://arxiv.org/abs/1512.03385>`_ for details
-    on the residual network architecture.
+    From `Deep Residual Learning for Image Recognition <https://arxiv.org/abs/1512.03385>`_ (He et al, 2015).
 
     Args:
-        model_name (str): Name of the ResNet model instance. Either ["resnet18", "resnet34", "resnet50", "resnet101",
-            "resnet152"].
-        num_classes (int): Number of classes for the model.
-        pretrained (bool): If true, use ImageNet pretrained weights. (default: ``False``).
-        groups (int): Number of filter groups for the 3x3 convolution layer in bottleneck blocks. (default: ``1``).
-        width_per_group (int): Initial width for each convolution group. Width doubles after each stage.
-            (default:  ``64``).
+        model_name (str): Name of the ResNet model instance. Either [``"resnet18"``, ``"resnet34"``, ``"resnet50"``, ``"resnet101"``,
+            ``"resnet152"``].
+        num_classes (int, optional): The number of classes. Needed for classification tasks. Default: ``1000``.
+        pretrained (bool, optional): If True, use ImageNet pretrained weights. Default: ``False``.
+        groups (int, optional): Number of filter groups for the 3x3 convolution layer in bottleneck blocks. Default: ``1``.
+        width_per_group (int, optional): Initial width for each convolution group. Width doubles after each stage.
+            Default: ``64``.
         initializers (List[Initializer], optional): Initializers for the model. ``None`` for no initialization.
-            (default: ``None``).
+            Default: ``None``.
+
+    Example:
+
+    .. testcode::
+
+        from composer.models import ComposerResNet
+
+        model = ComposerResNet(model_name='resnet18')  # creates a torchvision resnet18 for image classification
     """
 
     valid_model_names = ["resnet18", "resnet34", "resnet50", "resnet101", "resnet152"]
@@ -31,7 +42,7 @@ class ComposerResNet(ComposerClassifier):
     def __init__(
         self,
         model_name: str,
-        num_classes: int,
+        num_classes: int = 1000,
         pretrained: bool = False,
         groups: int = 1,
         width_per_group: int = 64,
