@@ -1,5 +1,8 @@
 # Copyright 2021 MosaicML. All Rights Reserved.
 
+"""General `YAHP <https://docs.mosaicml.com/projects/yahp/en/stable/README.html>`_ interface for
+ComposerTransformers."""
+
 from abc import ABC
 from dataclasses import dataclass
 from typing import Dict, Optional
@@ -9,10 +12,21 @@ import yahp as hp
 from composer.core.types import JSON
 from composer.models.model_hparams import ModelHparams
 
+__all__ = ["TransformerHparams"]
+
 
 @dataclass
 class TransformerHparams(ModelHparams, ABC):
-    """Defines the necessary hyparameters for a Transformer base module."""
+    """Defines the necessary hyparameters for a Transformer base module.
+
+    Args:
+        pretrained_model_name (str): "Pretrained model name to pull from Huggingface Model Hub."
+        model_config (Dict[str, JSON]): A dictionary providing a HuggingFace model configuration.
+        tokenizer_name (str): The tokenizer used for this model,
+            necessary to assert required model inputs.
+        use_pretrained (bool, optional): Whether to initialize the model with the pretrained weights. Default: ``False``
+        gradient_checkpointing (bool, optional): Use gradient checkpointing. Default: ``False``.
+    """
 
     tokenizer_name: str = hp.optional("Tokenizer name to pull from Huggingface Model Hub.", default=None)
     pretrained_model_name: Optional[str] = hp.optional(
