@@ -1,6 +1,7 @@
 # Copyright 2021 MosaicML. All Rights Reserved.
 
-import contextlib
+"""A U-Net model extending :class:`.ComposerModel`."""
+
 import logging
 import textwrap
 from typing import Any, Optional, Tuple
@@ -15,16 +16,22 @@ from composer.models.unet.model import UNet as UNetModel
 
 log = logging.getLogger(__name__)
 
+__all__ = ["UNet"]
+
 
 class UNet(ComposerModel):
-    """A U-Net model extending :class:`ComposerClassifier`.
+    """A U-Net model extending :class:`.ComposerModel`.
 
-    See this `paper <https://arxiv.org/abs/1505.04597>`_ for details on the U-Net architecture.
+    See U-Net: Convolutional Networks for Biomedical Image Segmentation (`Ronneberger et al, 2015`_)
+    on the U-Net architecture.
+
+    Args:
+        num_classes (int): The number of classes. Needed for classification tasks. Default: ``3``.
+
+    .. _Ronneberger et al, 2015: https://arxiv.org/abs/1505.04597
     """
 
-    n_classes: Optional[int] = None
-
-    def __init__(self) -> None:
+    def __init__(self, num_classes: Optional[int] = 3) -> None:
         super().__init__()
         try:
             from monai.losses import DiceLoss
@@ -36,18 +43,13 @@ class UNet(ComposerModel):
 
         self.module = self.build_nnunet()
 
-        self.dice = Dice(3)
-
+        self.dice = Dice(num_classes=num_classes)
         self.dloss = DiceLoss(include_background=False, softmax=True, to_onehot_y=True, batch=True)
         self.closs = nn.CrossEntropyLoss()
 
-    def loss(self, outputs: Any, batch: BatchPair) -> Tensors:
-
+    def loss(self, outputs: Any, batch: BatchPair, *args, **kwargs) -> Tensors:
         _, y = batch
         y = y.squeeze(1)  # type: ignore
-
-        assert isinstance(y, Tensor)
-
         loss = self.dloss(outputs, y)
         loss += self.closs(outputs, y[:, 0].long())
         return loss
@@ -57,18 +59,12 @@ class UNet(ComposerModel):
         return torch.stack([out[name] for out in outputs]).mean(dim=0)
 
     def metrics(self, train: bool = False) -> Metrics:
-
         return self.dice
 
     def forward(self, batch: BatchPair) -> Tensor:
         x, _ = batch
-        context = contextlib.nullcontext if self.training else torch.no_grad
-
         x = x.squeeze(1)  # type: ignore
-
-        with context():
-            logits = self.module(x)
-
+        logits = self.module(x)
         return logits
 
     def inference2d(self, image):
@@ -92,22 +88,20 @@ class UNet(ComposerModel):
 
     def validate(self, batch: BatchPair) -> Tuple[Any, Any]:
         assert self.training is False, "For validation, model must be in eval mode"
-
-        img, lbl = batch
-        pred = self.inference2d(img)
-        return pred, lbl[:, 0].long()  # type: ignore
+        image, target = batch
+        pred = self.inference2d(image)
+        return pred, target[:, 0].long()  # type: ignore
 
     def build_nnunet(self) -> torch.nn.Module:
         kernels = [[3, 3]] * 6
         strides = [[1, 1]] + [[2, 2]] * 5
-
         model = UNetModel(in_channels=4,
                           n_class=4,
                           kernels=kernels,
                           strides=strides,
                           dimension=2,
                           residual=True,
-                          normalization_layer="instance",
+                          normalization_layer="batch",
                           negative_slope=0.01)
 
         return model
