@@ -18,17 +18,21 @@ from composer.algorithms import AlgorithmHparams, get_algorithm_registry
 from composer.callbacks import (CallbackHparams, GradMonitorHparams, LRMonitorHparams, MemoryMonitorHparams,
                                 RunDirectoryUploaderHparams, SpeedMonitorHparams)
 from composer.core.types import JSON, Precision
-from composer.datasets import DataloaderHparams, DatasetHparams
+from composer.datasets import DataLoaderHparams, DatasetHparams
 from composer.datasets.dataset_registry import get_dataset_registry
 from composer.datasets.evaluator import EvaluatorHparams
 from composer.loggers import (FileLoggerHparams, InMemoryLoggerHparams, LoggerCallbackHparams, TQDMLoggerHparams,
                               WandBLoggerHparams)
 from composer.models import (BERTForClassificationHparams, BERTHparams, CIFARResNet9Hparams, CIFARResNetHparams,
                              DeepLabV3Hparams, EfficientNetB0Hparams, GPT2Hparams, MnistClassifierHparams, ModelHparams,
-                             ResNetHparams, TimmHparams, UnetHparams)
+                             ResNetHparams, SSDHparams, TimmHparams, UnetHparams, ViTSmallPatch16Hparams)
 from composer.models.resnet20_cifar10.resnet20_cifar10_hparams import CIFARResNet20Hparams
-from composer.optim import (AdamHparams, AdamWHparams, DecoupledAdamWHparams, DecoupledSGDWHparams, OptimizerHparams,
-                            RAdamHparams, RMSPropHparams, SchedulerHparams, SGDHparams, scheduler)
+from composer.optim import (AdamHparams, AdamWHparams, ConstantSchedulerHparams, CosineAnnealingSchedulerHparams,
+                            CosineAnnealingWarmRestartsSchedulerHparams, CosineAnnealingWithWarmupSchedulerHparams,
+                            DecoupledAdamWHparams, DecoupledSGDWHparams, ExponentialSchedulerHparams,
+                            LinearSchedulerHparams, LinearWithWarmupSchedulerHparams, MultiStepSchedulerHparams,
+                            MultiStepWithWarmupSchedulerHparams, OptimizerHparams, PolynomialSchedulerHparams,
+                            RAdamHparams, RMSpropHparams, SchedulerHparams, SGDHparams, StepSchedulerHparams)
 from composer.profiler.profiler_hparams import JSONTraceHandlerHparams, ProfilerEventHandlerHparams
 from composer.trainer.ddp import DDPSyncStrategy
 from composer.trainer.devices import CPUDeviceHparams, DeviceHparams, GPUDeviceHparams
@@ -48,25 +52,26 @@ optimizer_registry = {
     "radam": RAdamHparams,
     "sgd": SGDHparams,
     "decoupled_sgdw": DecoupledSGDWHparams,
-    "rmsprop": RMSPropHparams,
+    "rmsprop": RMSpropHparams,
 }
 
 scheduler_registry = {
-    "step": scheduler.StepLRHparams,
-    "multistep": scheduler.MultiStepLRHparams,
-    "exponential": scheduler.ExponentialLRHparams,
-    "linear_decay": scheduler.LinearLRHparams,
-    "cosine_decay": scheduler.CosineAnnealingLRHparams,
-    "cosine_warmrestart": scheduler.CosineAnnealingWarmRestartsHparams,
-    "constant": scheduler.ConstantLRHparams,
-    "polynomial": scheduler.PolynomialLRHparams,
-    "multistep_with_warmup": scheduler.MultiStepWithWarmupLRHparams,
-    "linear_decay_with_warmup": scheduler.LinearWithWarmupLRHparams,
-    "cosine_decay_with_warmup": scheduler.CosineAnnealingWithWarmupLRHparams,
+    "step": StepSchedulerHparams,
+    "multistep": MultiStepSchedulerHparams,
+    "exponential": ExponentialSchedulerHparams,
+    "linear_decay": LinearSchedulerHparams,
+    "cosine_decay": CosineAnnealingSchedulerHparams,
+    "cosine_warmrestart": CosineAnnealingWarmRestartsSchedulerHparams,
+    "constant": ConstantSchedulerHparams,
+    "polynomial": PolynomialSchedulerHparams,
+    "multistep_with_warmup": MultiStepWithWarmupSchedulerHparams,
+    "linear_decay_with_warmup": LinearWithWarmupSchedulerHparams,
+    "cosine_decay_with_warmup": CosineAnnealingWithWarmupSchedulerHparams,
 }
 
 model_registry = {
     "unet": UnetHparams,
+    "ssd": SSDHparams,
     "deeplabv3": DeepLabV3Hparams,
     "efficientnetb0": EfficientNetB0Hparams,
     "resnet56_cifar10": CIFARResNetHparams,
@@ -77,7 +82,8 @@ model_registry = {
     "gpt2": GPT2Hparams,
     "bert": BERTHparams,
     "bert_classification": BERTForClassificationHparams,
-    "timm": TimmHparams
+    "timm": TimmHparams,
+    "vit_small_patch16": ViTSmallPatch16Hparams
 }
 
 dataset_registry = get_dataset_registry()
@@ -122,7 +128,7 @@ class TrainerHparams(hp.Hparams):
             .. seealso:: :mod:`composer.datasets` for datasets built into Composer.
         train_batch_size (int): The optimization batch size to use for training. This is the total batch
             size that is used to produce a gradient for the optimizer update step.
-        dataloader (DataloaderHparams): Hparams used for constructing the dataloader which will be used
+        dataloader (DataLoaderHparams): Hparams used for constructing the dataloader which will be used
             for loading the train dataset and (if provided) the validation dataset.
         max_duration (str): The maximum duration to train as a str (e.g. ``1ep``, or ``10ba``).
             Will be converted to a :class:`~composer.core.Time` object.
@@ -180,13 +186,18 @@ class TrainerHparams(hp.Hparams):
             run during training. (default: ``[]``)
 
             .. seealso:: :mod:`composer.callbacks` for the different callbacks built into Composer.
-        load_path (str, optional): See :class:`.Trainer`.
+        load_path_format (str, optional): See :class:`.Trainer`.
         load_object_store (ObjectStoreProvider, optional): See :class:`.Trainer`.
         load_weights_only (bool, optional): See :class:`.Trainer`.
         load_chunk_size (int, optional): See :class:`.Trainer`.
-        save_folder (str, optional): See :class:`.Trainer`.
-        save_interval (str, optional): See :class:`.Trainer`.
-        save_compression (str, optional): See :class:`.Trainer`.
+        save_folder (str, optional): See :class:`~composer.callbacks.checkpoint_saver.CheckpointSaver`.
+        save_name_format (str, optional): See :class:`~composer.callbacks.checkpoint_saver.CheckpointSaver`.
+        save_latest_format (str, optional): See
+            :class:`~composer.callbacks.checkpoint_saver.CheckpointSaver`.
+        save_overwrite (str, optional): See :class:`~composer.callbacks.checkpoint_saver.CheckpointSaver`.
+        save_weights_only (bool, optional): See :class:`~composer.callbacks.checkpoint_saver.CheckpointSaver`.
+        save_interval (str, optional): See
+            :class:`~composer.callbacks.callback_hparams.CheckpointSaverHparams`.
         train_subset_num_batches (int, optional): See :class:`.Trainer`.
         eval_subset_num_batches (int, optional): See :class:`.Trainer`.
         deepspeed_config (Dict[str, JSON], optional): If set to a dict will be used for as the DeepSpeed
@@ -232,7 +243,7 @@ class TrainerHparams(hp.Hparams):
     train_dataset: DatasetHparams = hp.required(doc="Training dataset hparams")
     train_batch_size: int = hp.required(
         doc="batch size for each optimization step, across all devices and gradient accumulations.")
-    dataloader: DataloaderHparams = hp.required(doc="dataloader hparams")
+    dataloader: DataLoaderHparams = hp.required(doc="dataloader hparams")
 
     # duration
     max_duration: str = hp.required(doc="Time string for the maximum training duration (e.g., 90ep)")
@@ -297,49 +308,44 @@ class TrainerHparams(hp.Hparams):
     callbacks: List[CallbackHparams] = hp.optional(doc="Callback hparams", default_factory=list)
 
     # load checkpoint
-    load_path: Optional[str] = hp.optional(doc=textwrap.dedent("""\
+    load_path_format: Optional[str] = hp.optional(doc=textwrap.dedent("""\
         If specified, the path to an existing checkpoint file
         (if the checkpoint is on the local disk) or the object name for the checkpoint
         (if the checkpoint is in a cloud bucket). Set to None (the default) to skip loading from a checkpoint."""),
-                                           default=None)
+                                                  default=None)
     load_object_store: Optional[ObjectStoreProviderHparams] = hp.optional(doc=textwrap.dedent("""\
         If the checkpoint is in an object store (i.e. AWS S3 or Google Cloud Storage), the parameters for
         connecting to the cloud provider object store. Otherwise, if the checkpoint is a local filepath,
-        leave blank. This parameter has no effect if `load_path` is not specified."""),
+        leave blank. This parameter has no effect if `load_path_format` is not specified."""),
                                                                           default=None)
     load_weights_only: bool = hp.optional(doc=textwrap.dedent("""\
         Whether to only load the weights from the model.
-        This parameter has no effect if `load_path`is not specified."""),
+        This parameter has no effect if `load_path_format`is not specified."""),
                                           default=False)
     load_strict_model_weights: bool = hp.optional(doc=textwrap.dedent("""\
         Ensure that the set of checkpoint weights in the checkpoint and model must exactly match.
-        This parameter has no effect if `load_path` is not specified."""),
+        This parameter has no effect if `load_path_format` is not specified."""),
                                                   default=False)
 
     load_chunk_size: int = hp.optional(doc=textwrap.dedent("""\
         Chunk size (in bytes) to use when downloading checkpoints.
-        This parameter has no effect if `load_path` is not specified or it is a local file path."""),
+        This parameter has no effect if `load_path_format` is not specified or it is a local file path."""),
                                        default=1_048_576)
     load_progress_bar: bool = hp.optional(doc=textwrap.dedent("""\
         Whether to show a progress bar when downloading checkpoints.
-        This parameter has no effect if `load_path` is not specified or it is a local file path."""),
+        This parameter has no effect if `load_path_format` is not specified or it is a local file path."""),
                                           default=True)
 
     # save checkpoint
-    save_folder: Optional[str] = hp.optional(doc=textwrap.dedent(f"""\
-        Folder to save checkpoint files, relative to the run directory.
-        Defaults to None, meaning checkpoints will not be saved."""),
-                                             default=None)
-    save_interval: str = hp.optional(doc=textwrap.dedent("""\
-        The time string interval representing how frequently checkpoints should be saved.
-        For example, set to "1ep" to save checkpoints every epoch, or "10ba"
-        to save checkpoints every 10 batches.
-        This parameter has no effect if `save_folder` is not specified."""),
+    save_folder: Optional[str] = hp.optional(doc="Folder where checkpoints will be saved.", default=None)
+    save_name_format: str = hp.optional("Checkpoint name format string.", default="ep{epoch}-ba{batch}-rank{rank}")
+    save_latest_format: str = hp.optional("Latest checkpoint symlink format string.", default="latest-rank{rank}")
+    save_overwrite: bool = hp.optional("Whether to override existing checkpoints.", default=False)
+    save_weights_only: bool = hp.optional("Whether to save only checkpoint weights", default=False)
+    save_interval: str = hp.optional(textwrap.dedent("""\
+        Checkpoint interval or path to a `(State, Event) -> bool` function
+        returning whether a checkpoint should be saved."""),
                                      default="1ep")
-    save_compression: Optional[str] = hp.optional(doc=textwrap.dedent("""\
-        Compression algorithm to run on checkpoints. Can be `gzip`, `bzip2`,
-        `lzma`, or `None` for no compression.  (default: ``None`` for no compression)."""),
-                                                  default=None)
 
     # subset parameters
     train_subset_num_batches: Optional[int] = hp.optional(
@@ -420,7 +426,12 @@ class TrainerHparams(hp.Hparams):
         super().validate()
 
         if self.deepspeed is not None:
-            zero_stage = cast(int, self.deepspeed.get("zero_stage", 0))
+            self.deepspeed["steps_per_print"] = cast(int, self.deepspeed.get("steps_per_print", 1e20))
+
+            if "zero_optimization" in self.deepspeed:
+                zero_stage = cast(dict, self.deepspeed["zero_optimization"]).get("stage", 0)
+            else:
+                zero_stage = 0
 
             if self.deterministic_mode and zero_stage > 0:
                 raise ValueError("Deepspeed with zero stage > 0 is not compatible with deterministic mode")
@@ -464,6 +475,8 @@ class TrainerHparams(hp.Hparams):
         seed = self.seed if self.seed else reproducibility.get_random_seed()
         # need to set seed before model initialization for determinism
         # don't need to set different seeds per process since only the rank 0 initialization is used
+        # Algorithms should not use the `seed` on `__init__` but rather on `Event.INIT`, which occurs
+        # after the seed was properly distributed across ranks to ensure checkpoint compatibility
         reproducibility.seed_all(seed)
 
         model = self.model.initialize_object()
@@ -573,7 +586,7 @@ class TrainerHparams(hp.Hparams):
             torch_prof_with_flops=self.torch_prof_with_flops,
 
             # Checkpoint parameters
-            load_path=self.load_path,
+            load_path_format=self.load_path_format,
             load_object_store=self.load_object_store.initialize_object()
             if self.load_object_store is not None else None,
             load_weights_only=self.load_weights_only,
@@ -581,8 +594,10 @@ class TrainerHparams(hp.Hparams):
             load_chunk_size=self.load_chunk_size,
             load_progress_bar=self.load_progress_bar,
             save_folder=self.save_folder,
+            save_overwrite=self.save_overwrite,
+            save_name_format=self.save_name_format,
             save_interval=self.save_interval,
-            save_compression=self.save_compression,
+            save_weights_only=self.save_weights_only,
 
             # Subset parameters
             train_subset_num_batches=self.train_subset_num_batches,
